/*!
 * @copyright
 * Copyright Research In Motion Limited, 2013
 * Research In Motion Limited. All rights reserved.
 */

#ifndef BB_PLATFORM_IDENTITY_BLACKBERRYPROFILENOTIFICATION_HPP
#define BB_PLATFORM_IDENTITY_BLACKBERRYPROFILENOTIFICATION_HPP

#include <bb/platform/Global>
#include <QtDeclarative/QtDeclarative>

namespace bb {
namespace platform {
namespace identity {

/*!
 * @headerfile BlackBerryProfileNotification.hpp <bb/platform/identity/BlackBerryProfileNotification>
 * @brief The kinds of notifications that can be generated by this provider.
 * @xmlonly
 * <library name="bbplatform" />
 * <apigrouping group="Platform/Identity" />
 * @endxmlonly
 */
class BB_PLATFORM_EXPORT BlackBerryProfileNotification {
    Q_GADGET
    Q_ENUMS( Type )
public:
    enum Type {
        /*!<
         * @brief Notifications will now be sent for this entry.
         * @details The request to receive notifications was successful. Change
         * notifications will now be sent.
         */
        Started = 0,

        /*!<
         * @brief Notifications will no longer be sent for this entry.
         * @details The request to stop receiving notifications was successful, or
         * the request to start receiving notifications has failed. Change notifications
         * will NOT be sent.
         */
        Stopped = 1,

        /*!<
         * @brief The entry has changed.
         * @details The provider has detected that the entry has changed and is
         * notifying the application. A change can include the entry being created,
         * deleted, or modified.
         */
        Changed = 2
    };

private:
    //!@cond PRIVATE
    BlackBerryProfileNotification();
    ~BlackBerryProfileNotification();
    //!@endcond PRIVATE
};

} // namespace identity
} // namespace platform
} // namespace bb

QML_DECLARE_TYPE( bb::platform::identity::BlackBerryProfileNotification )

#endif /* BB_PLATFORM_IDENTITY_BLACKBERRYPROFILENOTIFICATION_HPP */
